<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=fon
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Lɛkɔ yì atɛ bi jí',
	'access_mode_texte' => 'ɖè tɛmɛ nu wiwlantɔn xlɛ  do atɛ ɔ ji ',
	'admin_debug' => 'Mi bló ɖó',
	'admin_modifier_article' => 'Hɔntogbó',
	'admin_modifier_auteur' => 'ɖiɔ nyɔwlantɔ é lɔ',
	'admin_modifier_breve' => 'ɖiɔ xogbè kléwun é lɔ',
	'admin_modifier_mot' => 'ɖiɔ gbèta é lɔ',
	'admin_modifier_rubrique' => 'ɖiɔ akpa  é lɔ',
	'admin_recalculer' => 'mi lɛ vɔ akɔnta wekpa tɔn blo',
	'alerte_maj_impossible' => 'Jijladó SQL tɔn soyí ɖìdè ɖévomɛ gló, e siwu nyí ɖɔ acɛ e na  yí do ɖiɔ titomɛ ɔ wɛ zɔn. Mi tɛnkpɔ bó so alɔ xwétɔ́ mi tɔn',
	'analyse_xml' => 'Ni kpon XML tri tri ton',
	'articles_recents' => 'wekpa gùdogùdotɔn lɛ̂  ',
	'avis_archive_incorrect' => 'gbètakin xóxó é lɔ é nyi gbètakin supipu tɔn a',
	'avis_archive_invalide' => 'gbètakɛn xoxo ɔ fɛwu a',
	'avis_attention' => 'Mi cɔ mi ɖé',
	'avis_champ_incorrect_type_objet' => 'nyikɔmasɔgbe@name@ nu kwin alɔkpa@type@',
	'avis_colonne_inexistante' => 'Akpa a tin a ',
	'avis_erreur' => 'afɔkiklɛn : mi kpɔn do',
	'avis_erreur_connexion' => 'afɔkiklɛn do cacadomɛ',
	'avis_erreur_cookie' => '',
	'avis_erreur_fonction_contexte' => 'afɔkiklɛn do titomɛ. ɖidè é lɔ do na tɔn do akpa é lɔ mɛ a', # MODIF
	'avis_erreur_mysql' => 'afɔkiklɛn SQL tɔn',
	'avis_erreur_sauvegarde' => 'afɔkiklɛn do wiwlihɛn ɔ mɛ(@type@ @id_objet@) !',

	// B
	'barre_a_accent_grave' => 'Mi zé wèkwin A bo xwè gbakun yi do na',
	'barre_aide' => 'Mi zan wékwin lɛ̂ bo ná ɖo blo titomɛ mitɔn ɖo',
	'barre_e_accent_aigu' => 'mi ze wékwin asi E  démɛ',
	'barre_eo' => 'mi ze wékwin asi E  ɖo l’o',
	'barre_eo_maj' => 'mi ze wékwin asi E  ɖo l’o daxo ɔ mɛ', # MODIF
	'barre_euro' => 'mi ze wékwin  é lɔ € ɖémɛ ',
	'barre_gras' => 'mi ze ɖo kpinkpɛnmɛ',
	'barre_guillemets' => 'mi ze « ɖiɖɔtɔ » sɔ lilɛ ɖo',
	'barre_guillemets_simples' => 'mi ze « ɖiɖɔtɔ » sɔ lilɛ ɖo akpa wègɔ̂ ji',
	'barre_intertitre' => 'mi lilɛ ɖo {{{gbèta tɛntin}}}',
	'barre_italic' => 'mi gban wiwlan kpɛɖé',
	'barre_lien' => 'mi lilɛ ɖo [lien hypertexte->http://...]',
	'barre_lien_input' => 'Mi ɖo gesi nu gblogbloji mi tɔn ( mi siwu doxlɛ atɛ ɖo http://www.gblogblojice/com alo mi na xlɛ wékpa ɖokpo.',
	'barre_note' => 'mi lilɛ ɖo[[Note de bas de page]]',
	'barre_quote' => 'Mi xlɛ wɛn ɖokpo',
	'bouton_changer' => 'ɖyɔ̂',
	'bouton_chercher' => 'Bà',
	'bouton_choisir' => 'Cyán',
	'bouton_download' => 'Télécharger', # MODIF
	'bouton_radio_desactiver_messagerie_interne' => 'Mi jo wiwlanmɛ ɖo ',
	'bouton_radio_envoi_annonces' => 'mi sɛ gbètàxojla do',
	'bouton_radio_non_envoi_annonces' => 'mi sɛ xojla do wo ',
	'bouton_radio_non_envoi_liste_nouveautes' => 'mi ma pklé xogbè yɔyɔ lɛ̂ do ',
	'bouton_recharger_page' => 'mi lɛ vɔ wékpa e lɔ ze',
	'bouton_telecharger' => 'ɖɔn',
	'bouton_upload' => 'ɖɔn', # MODIF
	'bouton_valider' => 'sɔ kɛn na',

	// C
	'cal_apresmidi' => 'Hwèlɛkɔ',
	'cal_jour_entier' => 'Akán ɔ bí',
	'cal_matin' => 'zânzan',
	'cal_par_jour' => 'Tìtómɛ gbèɖókpó ɖókpó tɔn',
	'cal_par_mois' => 'Tìtómɛ sùnɖókpó ɖókpó tɔn',
	'cal_par_semaine' => 'Tìtómɛ vòdúngblámɛɖókpó ɖókpó tɔn',
	'confirm_changer_statut' => 'vlɛ mī byɔ ɖɔ é mí ján ɖyɔ nǔ é lɔ. Mì ɖò bibà ɖɔ azɔ ná lɛ vɔ yì nù kɔn a ',

	// D
	'date_aujourdhui' => 'é gbé',
	'date_avant_jc' => 'có hwɛ kpó J.C ná wá',
	'date_dans' => 'dò@gbè sisɔmɛ@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@azán@ @ sùn nyíkɔ',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@azán@ @ sùn nyíkɔ',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'sɔ̄',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ à @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@ sùn nyíkɔ@xwè@',
	'date_fmt_nomjour_date' => 'le @nomjour@ @date@',
	'date_heures' => 'Gàn lɛ mɛ',
	'date_hier' => 'Sɔ̄ è wá yí ɔ ',
	'date_il_y_a' => 'il y a @delai@',
	'date_jnum1' => 'Nùkɔn nùkɔn tɔn ɔ ',
	'date_jnum10' => 'Wǒ',
	'date_jnum11' => 'wô ɖòkpó',
	'date_jnum12' => 'wěwé',
	'date_jnum13' => 'wǎtɔn ',
	'date_jnum14' => 'wɛnɛ',
	'date_jnum15' => 'afɔtɔn ',
	'date_jnum16' => 'afɔtɔn nùkún ɖókpó',
	'date_jnum17' => 'afɔtɔn nùkún wè',
	'date_jnum18' => 'afɔtɔn nùkún atɔn',
	'date_jnum19' => 'afɔtɔn nùkún ɛnɛ',
	'date_jnum2' => 'wè',
	'date_jnum20' => 'kò',
	'date_jnum21' => 'ko nùkún ɖókpó',
	'date_jnum22' => 'ko nùkún wè',
	'date_jnum23' => 'ko nùkún atɔn',
	'date_jnum24' => 'ko nùkún nɛ',
	'date_jnum25' => 'ko nùkún àtɔ̂n',
	'date_jnum26' => 'ko nùkún àyzɛn ',
	'date_jnum27' => 'ko nùkún tɛnwè',
	'date_jnum28' => 'ko nùkún tántɔn',
	'date_jnum29' => 'ko nùkún tɛnnɛ',
	'date_jnum3' => 'Atɔn',
	'date_jnum30' => 'gbàn',
	'date_jnum31' => 'gbàn nùkún ɖókpó',
	'date_jnum4' => 'ɛ̄nɛ',
	'date_jnum5' => 'àtɔ̂n',
	'date_jnum6' => 'àyízɛn ',
	'date_jnum7' => 'tɛnwè',
	'date_jnum8' => 'tántɔn',
	'date_jnum9' => 'tɛnnɛ',
	'date_jour_1' => 'vodunzangbè',
	'date_jour_2' => 'tɛnigbè',
	'date_jour_3' => 'tâtàgbè',
	'date_jour_4' => 'azangagbè',
	'date_jour_5' => 'nyɔnúzángbè',
	'date_jour_6' => 'axózangbè',
	'date_jour_7' => 'síɖígbè',
	'date_jours' => 'azan lɛ̂',
	'date_minutes' => 'cɛjúmɛ ',
	'date_mois' => 'sùn',
	'date_mois_1' => 'Alǔunsun',
	'date_mois_10' => 'Kɔnyasun',
	'date_mois_11' => 'Abɔxwísun',
	'date_mois_12' => 'Wǒosun',
	'date_mois_2' => 'Zofínkplɔsun',
	'date_mois_3' => 'xwèjísun ',
	'date_mois_4' => 'Lidósun',
	'date_mois_5' => 'Nǔxwasun',
	'date_mois_6' => 'Ayidósun',
	'date_mois_7' => 'Liyasun',
	'date_mois_8' => 'Avuvɔsun',
	'date_mois_9' => 'Zǒsun',
	'date_saison_1' => 'avìvɔ hwènú',
	'date_saison_2' => 'plɛntân',
	'date_saison_3' => 'hwèsívɔ hwènú',
	'date_saison_4' => 'otɔmù',
	'date_semaines' => 'Vodúngbláɖòkpómɛ ',
	'dirs_commencer' => 'bó nú mī ná ɖó bɛ afɔ ɖó tè ji ɔ ',
	'dirs_preliminaire' => 'bibɛmɛ ɔ : mī byɔ gbè hwɛ',
	'dirs_probleme_droits' => 'Xó ɖò acɛ yíyí wú', # MODIF
	'dirs_repertoires_absents' => 'Mī mɔ ɖìɖèmɛ é lɛ áE siwú nyí ɖɔ wèkwín ɖáxó kpódo kpɛvi yé mà wlan ganji à wɛ zɔnmī kpɔn ɖɔ wèkwín ɖáxó kpódo kpɛvi é  lo ɖìɖèmɛ ɔ é sɔgbè kpó é xlɛ ànú é má nyí mɔ a mī lɛ ná nyikɔ FTP ɔ bó gɔn afɔ klɛnmī kò bló é nɛ fo ɔ', # MODIF
	'dirs_repertoires_suivants' => 'yé siwú wlán nú ɖó ɖìɖèmɛ é lɔ lɛ ánú é ná  ɖó kpɔn té ɔ, mī zé FTP bò ná Xó ɖò acɛ mɛɖókpó ɖókpó tɔn ɖó ɖìɖèmɛmī timɛ afɔ ɖìɖè ɔ ɖó ', # MODIF
	'double_occurrence' => 'Double occurrence', # MODIF

	// E
	'envoi_via_le_site' => 'mī sɛ gbɔn gblògblójí ɔ jì',

	// F
	'form_deja_inscrit' => 'mī kò ná nyìkɔ ',
	'form_email_non_valide' => 'e-mailù mī tɔn ɔ sɔ gbè á',
	'form_forum_access_refuse' => 'mī sɔ sǐwu yì gblogblo é lɔ jí á',
	'form_forum_bonjour' => 'mī fɔn án @nom@,',
	'form_forum_email_deja_enregistre' => 'gesí é lɔ kó sɔ gbè, mī sǐwu zán cávì mī tɔn ',
	'form_forum_identifiant_mail' => 'e-mailù ɖòkpó kó sɛ ɖéxlɛ mì tɔn ɖó',
	'form_forum_identifiants' => 'ɖéxlɛ mì tɔn ',
	'form_forum_indiquer_nom_email' => 'mī sɛ nyìkɔ mì tɔn kpòɖó e-mailù sɛ ɖó. mī ná sɛ ɖéxlɛ mì tɔn sɛ ɖó azɔn ɖòkpó gbɔn e-mailù jí',
	'form_forum_login' => 'nyìkɔ',
	'form_forum_message_auto' => 'é lɔ ɔ wɛn càcà wɛ',
	'form_forum_pass' => 'cávì :',
	'form_forum_probleme_mail' => 'Xó ɖò e-mailù ɔ wú : vlàvò ɔ ɖéxlɛ yì á',
	'form_forum_voici1' => 'ɖéxlɛ mì tɔn lɛ mì byɔ gblogblojí @nyìkɔ_gblogblojí_supipu@ ‘’gesí_gblogblojí@', # MODIF
	'form_forum_voici2' => 'ɖéxlɛ mì tɔn lɛ mì ná ɖó wl wèkpá ɖó gblogblojí @nyìkɔ_gblogblojí_supipu@ ‘’gesí_gblogblojí@', # MODIF
	'form_indiquer_email' => 'mī kɛnklɛn bó ná gèsí kpó e-mailù kpó',
	'form_indiquer_nom' => 'mī ná nyìkɔ mí tɔn ',
	'form_indiquer_nom_site' => 'mī ná gblogblojí mí tɔn sín nyìkɔ ',
	'form_pet_deja_enregistre' => 'mī kó wlí gblogblojí é lɔ hɛn ',
	'form_pet_signature_pasprise' => 'mī kó yígbè nú àlɔɖówěmámɛ mī tɔn á',
	'form_prop_confirmer_envoi' => 'mī kò sɛ ɖó hún, mī lɛ vɔ ɖɔ nú mí',
	'form_prop_description' => 'ɖìɖèxlɛ/ xóvánkán',
	'form_prop_enregistre' => 'Xógbè mī tɔn kó nyí wiwlíhɛntɔ, nú gblogblo ɔ jí sín gán lɛ sɔ kɛn ní ɔ, é ná tɔn tà ', # MODIF
	'form_prop_envoyer' => 'sɛ wɛn ɖòkpó ɖó',
	'form_prop_indiquer_email' => 'bó na e-mailù ɖágbé',
	'form_prop_indiquer_nom_site' => 'Mì gblogblo ɔ jí sín nyíkɔ.',
	'form_prop_indiquer_sujet' => 'mì xlɛ xógbè ɔ ',
	'form_prop_message_envoye' => 'wɛn ɔ yí',
	'form_prop_non_enregistre' => 'E siwú wlí Xógbè mì tɔn hɛn á',
	'form_prop_sujet' => 'Xógbè',
	'form_prop_url_site' => 'nɔtɛn (URLU) gblogblojí ɔ tɔn', # MODIF
	'forum_non_inscrit' => 'mì ná nyíkɔ , kàbí nɔtɛn, cávì lɛ nyɔ á.',
	'forum_par_auteur' => '@nyɔwlántɔ ɖókpóɖókpó@',
	'forum_titre_erreur' => 'mì klɛn àfɔ',

	// I
	'ical_texte_rss_articles' => 'Xótá « backend » wěkpblogblojí é lɔ tɔn ɖɔ nɔtɛn :',
	'ical_texte_rss_articles2' => 'Mi hɛn ɔ mi síwú yí Xótá « backend » nú      wěmà  ákpáxwé gblogblojí ɔ tɔn:',
	'ical_texte_rss_breves' => 'Xótá ɖé ɖè bó hɛn xó kléwún ɖé lɛ. Nú mi ɖɔ numɛló ákpáxwé ɔ tɔn, mi ná mɔ xògbè kléwún ákpáxwé énɛ ɔ tɔn.',
	'icone_a_suivre' => 'Bɔɖéwú',
	'icone_admin_site' => 'Gblogbojí sín tìtò',
	'icone_agenda' => 'Wègbó',
	'icone_aide_ligne' => 'àlɔdó',
	'icone_articles' => 'wěkpá',
	'icone_auteurs' => 'nyɔwlántɔ',
	'icone_brouteur' => 'numɛkéjé càcà',
	'icone_configuration_site' => 'Tìtòmɛ',
	'icone_configurer_site' => 'Mi tò gblogblojí ɔ',
	'icone_creer_nouvel_auteur' => 'Mi ɖè nyɔwlántɔ dévó tɔn',
	'icone_creer_rubrique' => 'Mi ɖè àkpáxwé dévó tɔn',
	'icone_creer_sous_rubrique' => 'Mi ɖè àkpáxwé dévó tɔn',
	'icone_deconnecter' => 'E Gósín kànnú',
	'icone_discussions' => 'Xókíjákìjà',
	'icone_doc_rubrique' => 'Wěmà àkpáxwé',
	'icone_ecrire_article' => 'Wlán wékpá dévó',
	'icone_edition_site' => 'Wègbó',
	'icone_gestion_langues' => 'tìtòmɛ gbè lɛ tɔn ',
	'icone_informations_personnelles' => 'xógbè mi tɔn',
	'icone_interface_complet' => 'àtɛ ɔ bí',
	'icone_interface_simple' => 'yè ɖè xógbè kpò ɖò àtɛ ɔ jí',
	'icone_maintenance_site' => 'Tìtòmɛ gblogblojí ɔ tɔn ',
	'icone_messagerie_personnelle' => 'wɛngbáví mi tɔn',
	'icone_repartition_debut' => 'mi sɔ ɖìɖèmɛ lɛ xlɛ sín bìbɛmɛ',
	'icone_rubriques' => 'àkpáxwé',
	'icone_sauver_site' => 'wlí gblogblojí ɔ hɛn',
	'icone_site_entier' => 'gblogblojí ɔ bí',
	'icone_sites_references' => 'gblogblojí yè tò',
	'icone_statistiques' => 'àkɔŋtá gblogblojí ɔ tɔn ',
	'icone_suivi_activite' => 'mi nɔ nùkɔn yìyì gblogblojí ɔ tɔn',
	'icone_suivi_actualite' => ' nùkɔn yìyì gblogblojí ɔ tɔn',
	'icone_suivi_pettions' => 'cɔ/tò xójíjlá lɛ',
	'icone_suivi_revisions' => '  ɖìɖyɔ wékpá lɛ tɔn',
	'icone_supprimer_document' => 'gbìɖí wěmà ɔ ',
	'icone_supprimer_image' => ' gbìɖí nú títɛ é lɔ',
	'icone_tous_articles' => 'wěkpá lɛ bí',
	'icone_tous_auteur' => 'nyɔwlántɔ lɛ bí',
	'icone_visiter_site' => 'Jónɔ', # MODIF
	'icone_voir_en_ligne' => 'Mi kpɔn ɖò àtɛ ɔ jí ',
	'img_indisponible' => 'Yɛ ɖébú ɖò àtɛ ɔ jí a',
	'info_a_suivre' => 'mi ná kpɔn',
	'info_acces_interdit' => 'yé ná gbè á',
	'info_acces_refuse' => 'yé ná gbè á',
	'info_action' => 'àzɔ',
	'info_administrer_rubriques' => 'tìtòtɔ é lɔ nɔ bló àkpáxwé é lɔ lɛ ɖó',
	'info_adresse_non_indiquee' => 'mi dó gesí á!',
	'info_aide' => 'àlɔdó :',
	'info_ajouter_mot' => 'mi gɔ xókwín dókpó  ná',
	'info_annonce' => 'xójíjlá',
	'info_annonces_generales' => 'xójíjlá kpa:',
	'info_article_propose' => 'wěkpá sɔ ɖáyì',
	'info_article_publie' => 'sɔ wěkpá ɔ xlɛ',
	'info_article_redaction' => 'yè kpò ɖò wěmà ɔ wlán wɛ',
	'info_article_refuse' => 'yè sɔ kɛn nú wěmâ',
	'info_article_supprime' => 'gbìɖí  wěmâ',
	'info_articles' => 'wěmâ',
	'info_articles_a_valider' => ' sɔ kɛn nú wěmà',
	'info_articles_proposes' => 'wěkpá sɔ ɖáyì',
	'info_auteurs_nombre' => 'Nyɔwlántɔ (lɛ̂):',
	'info_authentification_ftp' => 'Acɛ yíyí (FTP).',
	'info_breves_2' => 'xó kléwún lɛ',
	'info_connexion_refusee' => 'cácáɖó ɔ sɔgbè á',
	'info_contact_developpeur' => 'mi sɔ àlɔ tìtòtɔ ɔ.', # MODIF
	'info_contenance' => 'gblogblojí  élɔ ɖó:',
	'info_contribution' => 'àlɔɖó kplékplé ɔ tɔn ', # MODIF
	'info_copyright' => '@spip@ Azɔwànúmɛɖémákpàcɛná  @lien_gpl@',
	'info_copyright_doc' => 'nú mi ná lɛ ɖó mɔ xó dévó lɛ ɔ mi yì gblogblo é lɔ jí', # MODIF
	'info_copyright_gpl' => 'Ɖò Gbèníná GPL tɔn mɛ',
	'info_cours_edition' => 'mi kpó ɖò wékpá lɛ wlán wɛ ', # MODIF
	'info_creer_repertoire' => 'mi kɛnklɛn bó gbètàxókplé bó ná nyíkɔ ɛ:',
	'info_creer_repertoire_2' => 'àkpáxwé', # MODIF
	'info_creer_vignette' => 'Kunɖéwémá càca',
	'info_deplier' => 'mi vlɔn',
	'info_descriptif_nombre' => 'ɖìɖèmɛ:',
	'info_description' => 'ɖìɖèmɛ:',
	'info_description_2' => 'ɖìɖèmɛ:',
	'info_dimension' => 'ɖìɖèmɛ:',
	'info_ecire_message_prive' => 'wlán wɛn nú mɛ ɖê',
	'info_email_invalide' => 'yé sɔ kɛn ná e-mailù é lɔ á.',
	'info_en_cours_validation' => 'mi kpó ɖò wékpá lɛ wlán wɛ tion',
	'info_en_ligne' => 'é lò kànjí ɖìn :',
	'info_envoyer_message_prive' => 'mi sɛ wɛn ɖó mɛ ɔ ɖé sú',
	'info_erreur_requete' => 'mi klɛn àfɔ ɖò byɔná ɔ mɛ :',
	'info_erreur_squelette2' => 'Tìtòmɛ ɖébú ɖè á',
	'info_erreur_systeme' => 'wàlɔ̂ jàyí)',
	'info_fini' => 'E vɔ!',
	'info_format_image' => 'Nú títɛ lɛ ɖê yē zé bló gbètákɛn ná@.',
	'info_format_non_defini' => 'ɖèxlɛ ɔ sɔ gbè á',
	'info_grand_ecran' => 'Atɛ ɖàxó',
	'info_image_aide' => 'Alɔdó',
	'info_image_process_titre' => 'Mi cyán wàlɔ ɖàgbè lɛ',
	'info_impossible_lire_page' => 'Wémà ɔ gblé', # MODIF
	'info_installation_systeme_publication' => 'nyíkɔníná nyɔwlántɔ lɛ tɔn...',
	'info_installer_documents' => 'mi sɔ wémà lɛ sɛɖó càcà.', # MODIF
	'info_installer_ftp' => 'mi sɔ wémà lɛ sɛɖó càcà', # MODIF
	'info_installer_images' => 'mi síwú sɔ ɖìdè lɛ dó JPEG, GIF et PNG.',
	'info_installer_images_dossier' => 'mi síwú sɔ ɖìdè lɛ dó.', # MODIF
	'info_interface_complete' => 'Atɛ ɔ bí',
	'info_interface_simple' => 'Atɛ ɔ bí',
	'info_joindre_document_article' => 'Mi sɔ wémà càdó',
	'info_joindre_document_rubrique' => 'Mi sɔ wémà càdó',
	'info_joindre_documents_article' => 'Mi sɔ wémà càdó:',
	'info_l_article' => 'wékpá',
	'info_la_breve' => 'xó kléwûn ',
	'info_la_rubrique' => 'àkpáxwé',
	'info_langue_principale' => 'Gbètá gblogblojí ɔ tɔn',
	'info_largeur_vignette' => 'jíjlɛmɛ',
	'info_les_auteurs_1' => 'gbɔn@',
	'info_logo_format_interdit' => 'Ntùn é dò ɖéxlɛ lɛ kɛɖɛ@formats@  wɛ yè ɖègbè ná .',
	'info_logo_max_poids' => 'Ntùn lɛ dó ná gbló gègé à @maxi@ (xótòɖáyí é lɔ@actuel@).',
	'info_mail_fournisseur' => 'miɖê @nátɔ.com',
	'info_message_2' => 'wɛn',
	'info_message_supprime' => 'yè súsú wɛn',
	'info_mise_en_ligne' => 'Azán bíbló tɔn:',
	'info_modification_parametres_securite' => 'ɖìɖyɔ',
	'info_mois_courant' => 'sún ɖòkpó ɔ mɛ:',
	'info_mot_cle_ajoute' => 'zé gbètakɛn gɔná',
	'info_multi_herit' => 'Gbè ɖébú',
	'info_multi_langues_soulignees' => 'Nú mi sɔ gbè ɖé ɔ  é jɛ ɖɔ yè ná tínmɛ.', # MODIF
	'info_multilinguisme' => 'Gbèguèguè',
	'info_nom_non_utilisateurs_connectes' => 'nyíkɔ tɔn ɖò mɛ ɖò kánnú lɛ jí á.', # MODIF
	'info_nom_utilisateurs_connectes' => 'nyíkɔ mi tɔn nɔ tɔn  ɖò mɛ ɖò kánnú lɛ jí .', # MODIF
	'info_nombre_en_ligne' => 'é ló kânú dìn:',
	'info_non_resultat' => 'Xógbè ɖébú ɖè á"@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'mi ɖò Winwlántɛnmɛ gblogblojí ɔ tɔn bà wɛ.',
	'info_nouveau_message' => 'mi ɖò wɛn yɔyɔ ɖévó',
	'info_nouveaux_messages' => '@total_messages@ wɛn yɔyɔ',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'Lìntámɛ-Agúɖàgɔ',
	'info_petit_ecran' => 'Atɛ kpɛví',
	'info_pixels' => 'cíkícíkí',
	'info_plusieurs_mots_trouves' => 'Yé mɔ gbètákɛn gégé"@cherche_mot@":',
	'info_portfolio_automatique' => 'Portfolio càcà :',
	'info_premier_resultat' => '[@debut_limit@ premiers résultats sur @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ premiers résultats sur @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propose : @titre@',
	'info_propose_2' => 'Wékpá
---------------',
	'info_propose_3' => 'Wékpá "@titre@" Yé ná ɖɔ ɖó tò jí',
	'info_propose_4' => 'Yè ɖɔ mi ní wá kpɔn nú ɖê mi ɖɔ̂',
	'info_propose_5' => 'ɖò kplékplé cá ɖé wú ɔ, é ɖò nɔtɛn  :',
	'info_publie_01' => 'Wékpá"@titre@" yè sɔ kɛn ná @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIE : @titre@',
	'info_publie_2' => 'Wékpá yè sɔ kɛn ná
--------------',
	'info_rechercher' => 'Bìbà',
	'info_rechercher_02' => 'Bìbà :',
	'info_remplacer_vignette' => 'mi ɖyo syɔ :',
	'info_sans_titre_2' => 'Xótá ɖè á',
	'info_selectionner_fichier' => 'Mi síwú cyán gbètákɛn <i>cyán</i>', # MODIF
	'info_selectionner_fichier_2' => 'Mi cyán gbètákɛn :',
	'info_supprimer_vignette' => 'gbìdí  ɖìɖè ɔ ',
	'info_symbole_bleu' => 'kwínnɔ xlɛ gɔgúnɔ: é nyí wɛn mi ɖɛ ɖésú tɔn', # MODIF
	'info_symbole_jaune' => 'kwín  júnɔ nɔ xlɛ tìtòtɔ kpó nyɔwlántɔn hɛn ná ɖyɔ ', # MODIF
	'info_symbole_vert' => 'kwín   àmàmú nɔ xlɛ wɛn yé má xá mɛ ɖévó', # MODIF
	'info_telecharger_nouveau_logo' => 'ɖɔn sín mɔxwítíxwítí ɔ mɛ :',
	'info_telecharger_ordinateur' => 'ɖɔn sín mɔxwítíxwítí ɔ mɛ :',
	'info_tous_resultats_enregistres' => '[yé wlí xógbè lɛ bí hɛn]',
	'info_tout_afficher' => 'Xlɛ bí',
	'info_travaux_texte' => 'mi lɛkɔ wá Gblògblòjí é lɔ kò sɔgbè á...',
	'info_travaux_titre' => 'yé kpò ɖò àzɔ wá wɛ ɖò Gblògblòjí ɔ wú',
	'info_trop_resultat' => 'xógbè gégé"@cherche_mot@" ; mi lɛ vɔ bà núgbó tɔn',
	'info_utilisation_messagerie_interne' => 'mi lò wɛngbáví ɔ Gblògblòjí ɔ tɔn zán wɛ.',
	'info_valider_lien' => 'sɔ kɛn nú àlɔwlí ɔ',
	'info_verifier_image' => 'mi vɔ kpɔn ɖɔ ɖéxlɛ mi tɔn lɛ yì gànjí.',
	'info_vignette_defaut' => 'vìnyɛtù',
	'info_vignette_personnalisee' => 'vìnyɛtù',
	'info_visite' => 'jónɔ bìbá :',
	'info_vos_rendez_vous' => 'mi ná kpé mì ɖê',
	'infos_vos_pense_bete' => 'tàmɛ lìn àgúɖágɔ', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'jònɔ',
	'lien_afficher_texte_icones' => 'xlɛ wémà lɛ',
	'lien_afficher_texte_seul' => 'xlɛ wémà lɛ',
	'lien_liberer' => 'mi sɔ jó',
	'lien_liberer_tous' => 'mi sɔ wékpá lɛ  jó', # MODIF
	'lien_nouvea_pense_bete' => 'lìn tàmɛ àgúɖàgɔ',
	'lien_nouveau_message' => 'wɛn yɔyɔ',
	'lien_nouvelle_annonce' => 'wɛn yɔyɔ',
	'lien_petitions' => 'xó jíjlá',
	'lien_popularite' => 'Tòbítùn : @popularite@%',
	'lien_racine_site' => 'Gblogblojí O sín ɖòkɔ',
	'lien_reessayer' => 'mi lɛvɔ bló',
	'lien_repondre_message' => 'yígbjè nú wɛn é lɔ',
	'lien_supprimer' => 'Sùnsùn',
	'lien_tout_afficher' => 'xlɛ bí',
	'lien_visite_site' => 'mi bà jɔ gblogblojí ɔ  é lɔ',
	'lien_visites' => '@visites@ jònɔ bìbà lɛ',
	'lien_voir_auteur' => 'mi kpɔ nyɔwlántɔ é lɔ',
	'login_acces_prive' => 'àcɛ sɔ byɔ tɛnkánɖóvò',
	'login_autre_identifiant' => 'wlìalɔ sɔ gbɔn nyíkɔ ɖévò mɛ',
	'login_cookie_accepte' => 'mi tɛnkpɔn nú sàɖìdìtɔ mí lɛ ní xlɛ xógbè é lɔ lɛ .',
	'login_cookie_oblige' => 'Nú mi ná ɖé mi xlɛ ɔ mi ɖó yí koki lɛ.',
	'login_deconnexion_ok' => 'ɖè ɖò kánnú.',
	'login_erreur_pass' => 'klɛn àfɔ ɖò àcɛmɛ .',
	'login_espace_prive' => 'tɛnkánɖòfí',
	'login_identifiant_inconnu' => 'Yè tùn « @login@ » Nyíkɔ̂ á .',
	'login_login' => 'Nyíkɔ̂  :',
	'login_login2' => 'Nyíkɔ̂ (identifiant de connexion au site) :', # MODIF
	'login_login_pass_incorrect' => '(Nyíkɔ kàbí càvì ɔ gbo vò.)',
	'login_motpasseoublie' => 'Yé nyɔ gbètákɛn ɔ ?',
	'login_non_securise' => ' Nyíkɔ kàbí càvì ɔ gbo vò Yé nyɔ gbètákɛn ɔ',
	'login_nouvelle_tentative' => 'Mi lɛ vɔ bló ɖévó',
	'login_par_ici' => 'Yé kò yí nyíkɔ mi tɔn ... gbɔn  fí...',
	'login_pass2' => 'gbètákɛn :',
	'login_preferez_refuser' => 'Nú mi jlò ná gbɛ koli lɛ ɔ , wàlɔ ɖévó lɛ ɖè :',
	'login_recharger' => 'Mi lɛ vɔ ɖɔn wémà é lɔ ',
	'login_rester_identifie' => 'Mi jó mi ɖé ɖó nú yè ní mɔ mi nú àzán ywɛywɛ ɖé lɛ', # MODIF
	'login_retour_public' => 'Mi lɛkɔ yì gblogblojí ɔ ',
	'login_retour_site' => 'Mi lɛkɔ yì gblogblojí ɔ ',
	'login_retoursitepublic' => 'Mi lɛkɔ yì gblogblojí ɔ ',
	'login_sinscrire' => 'Ná nyíkɔ ', # MODIF
	'login_test_navigateur' => 'ɖèxlɛtɔ/àlɔwlí ɖévó',
	'login_verifiez_navigateur' => '(mi kpɔn ɖɔ ɖèxlɛtɔ yí gbètákɛn à jí ...)',

	// M
	'module_fichiers_langues' => 'gbè lɛ sín wěmà ',

	// N
	'navigateur_pas_redirige' => 'nú ɖéxlɛ mi tɔn má tɔn á, mi zín fí bó  lɛ vɔ yì.',

	// O
	'onglet_affacer_base' => 'mi sùnsùn xóxòkplé lɛ ',
	'onglet_auteur' => 'nyɔwlántɔ ɔ ',
	'onglet_contenu_site' => 'gblògblòjí sín àɖɔmɛ ',
	'onglet_evolution_visite_mod' => 'núkɔn yíyí ',
	'onglet_fonctions_avances' => 'wàlɔ xwítíxwítí',
	'onglet_informations_personnelles' => 'xó mɛ ɖé sú tɔn lɛ',
	'onglet_interactivite' => 'wàzɔ ɖókpɔ ',
	'onglet_messagerie' => 'wɛngbáví',
	'onglet_repartition_rubrique' => 'Mi tò àkpáxwé  lɛ',
	'onglet_save_restaur_base' => 'wlíhɛn/ lɛvɔ xóxòkplé blóɖó',
	'onglet_vider_cache' => 'Bɛ̂ ê é ɖò gbàví ɔ mɛ bí sín',

	// P
	'pass_choix_pass' => 'Mi sɔ càvì ɖévó :',
	'pass_erreur' => 'klɛn àfɔ ',
	'pass_erreur_acces_refuse' => 'klɛn àfɔ  mi sɔ yí gblogbloé lɔ jí á',
	'pass_erreur_code_inconnu' => 'mi sɔ yí gblogbloé lɔ jí á', # MODIF
	'pass_erreur_non_enregistre' => 'klɛn àfɔ  l’adresse <tt>@email_oubli@</tt> ɖò fí á.',
	'pass_erreur_non_valide' => 'klɛn àfɔ <tt>@email_oubli@</tt> ɖò fí á !',
	'pass_erreur_probleme_technique' => 'klɛn àfɔ  ɖò fí á',
	'pass_espace_prive_bla' => 'yé hùn fí nú mɛ bí á
 ', # MODIF
	'pass_forum_bla' => 'mi byɔ ɖɔ é mi ná ɖɔ xó ɖò kplékplé ɔ mɛ.', # MODIF
	'pass_indiquez_cidessous' => 'mi sɔ e-mailú mi tɔn xlɛ 
.',
	'pass_mail_passcookie' => 'Wɛn é lɔ wɛn càcà wɛ 
@nom_site_spip@ (@adresse_site@)

Nú mi ná ɖó mɔ nɔtɛn gblogblojí  é lɔ tɔn  mi yì
    @sendcookie@

', # MODIF
	'pass_mot_oublie' => 'mi yɔn càvì ɔ',
	'pass_nouveau_enregistre' => 'Mi sɔ càvì ɖévó.',
	'pass_nouveau_pass' => 'Mi sɔ càvì ɖévó',
	'pass_ok' => 'bà yí',
	'pass_oubli_mot' => 'mi yɔn càvì ɔ',
	'pass_quitter_fenetre' => 'jó flècè é lɔ ɖó',
	'pass_rappel_login' => 'nyíkɔ mi tɔn  « @login@ ».',
	'pass_recevoir_mail' => 'mi ná sɛ wɛn ɖê ná ɖɔ ɖé mi ná byɔ gblogblojí gbɔn é .', # MODIF
	'pass_retour_public' => 'gblogblojí',
	'pass_rien_a_faire_ici' => 'ŋ ɖé ɖò fí á.',
	'pass_vousinscrire' => 'nyíkɔ mi tɔn',
	'precedent' => 'E wà yì é',
	'previsualisation' => 'kpɔn',
	'previsualiser' => 'kpɔn',

	// S
	'stats_visites_et_popularite' => '@visites@ jónɔ ; tòbítùn : @popularite@',
	'suivant' => 'E jà wè',

	// T
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octets',
	'texte_actualite_site_1' => 'nú àtɛ wô má mì ɔ mi zìn fí ',
	'texte_actualite_site_2' => 'àtɛ',
	'texte_actualite_site_3' => 'mi ná sɔ mɔ àlì gégé.',
	'texte_creation_automatique_vignette' => 'wlíhɛn/ lɛvɔ xóxòkplé blóɖóBɛ̂ ê é ɖò gbàví ɔ mɛ bí sínZé gɔ ná wěmámɛYé mɔ àyì ɖé ɖó wékwín é lɔ wú áYé sɔ mɔ ɖê ná nɔ kpɔn wékwín sín winwlán gànjí ɔ ɖó sùpípùmɛ.Amɔ có nú mi ná sɔ wěmà mi tɔn ɖé xlɛ hún mi ván núkún ɖémɛ ɖésú hwɛ @gd_formats@, wékwín ɖê yé mà tùn à lɛ ɔ ɖò vɔvɔmɛ. Zìn yé bó kpɔn àyì é yè b ɖó yèwú ɔ@taille_preview@ ',
	'texte_documents_associes' => 'mi sɔ yí gblogblo é lɔ jí áyé hùn fí nú mɛ bí ámi byɔ ɖɔ é mi ná ɖɔ xó ɖò kplékplé ɔ mɛmi sɔ e-mailú mi tɔn xlɛ Wɛn é lɔ wɛn càcà wɛ .',
	'texte_erreur_mise_niveau_base' => 'xó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn mɔnɔ hɛnmi cyían ɖê jɛ ɖéwú ɔ', # MODIF
	'texte_inc_auth_1' => 'mi kó mɔ mi @auth_login@àmɔ mi sɔ ɖò xóxòkplégbàví ɔ mɛ á', # MODIF
	'texte_inc_auth_2' => 'mi lɛ vɔ yí kànjí',
	'texte_inc_auth_3' => ', vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  ',
	'texte_inc_config' => 'kpɔnjónɔ tòbítùntìto kléwúngbàví ɔ jɛ vɔwɛn é lɔ yé sɛ ɖó ɔ mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúɖò kplékplé yé sɔ ɖó dò wɔ mɛnú àtɛ wô má mì ɔ mi zìn fími ná sɔ mɔ àlì gégéwékpá é lɔxógbè lɛ nyɔwlántɔ lɛ gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn ', # MODIF
	'texte_inc_meta_1' => 'mi zìn fími ná sɔ mɔ àlì gégéwékpá é lɔxógbè lɛ nyɔwlántɔ lɛ gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛ', # MODIF
	'texte_inc_meta_2' => 'mi k pɔn àcɛ winwl tɔn ',
	'texte_inc_meta_3' => 'E ɖò àkpáxwé ɔ mɛ <code>@repertoire@</code>.', # MODIF
	'texte_statut_en_cours_redaction' => 'E kpó ɖò wíwlánwɛ',
	'texte_statut_poubelle' => 'sɔ nyígbè',
	'texte_statut_propose_evaluation' => 'Mi kpɔnɖɔ yé ná sɔ kɛn ná',
	'texte_statut_publie' => 'sɔɖò àtɛjí',
	'texte_statut_refuse' => 'yé gbɛ',
	'titre_ajouter_mot_cle' => 'zé gbètákɛn gɔná :',
	'titre_cadre_raccourcis' => 'xàsádó:',
	'titre_changer_couleur_interface' => 'ɖyɔ ŋtùn nú àtɛ ɔ',
	'titre_image_admin_article' => 'Mi hɛn ɔ mi ná tò wékpá é lɔ ',
	'titre_image_administrateur' => 'Tìtòtɔ', # MODIF
	'titre_image_aide' => 'Mi yí àlɔdó ɖò fí',
	'titre_image_auteur_supprime' => 'nyɔwlántɔn ɖê yé sùnsùn',
	'titre_image_redacteur' => 'nyɔwlántɔn  mà ɖò àcɛ',
	'titre_image_redacteur_02' => 'nyɔwlántɔn  ',
	'titre_image_visiteur' => 'Jónɔ',
	'titre_joindre_document' => 'Zé wěmà gɔná ',
	'titre_mots_cles' => 'gbètákɛn',
	'titre_probleme_technique' => 'mɛɖé sɔ sí byɔ fínɛ á.',
	'titre_publier_document' => 'mi sɔ wěmà xlɛ ɖò àkpáxwé lɔ jí',
	'titre_statistiques' => 'akɔŋtá gblogblojí  ɔ tɔn ',
	'titre_titre_document' => 'xótá wěmà tɔn :',
	'trad_reference' => '(wékpá jɔ wékpá)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' :Dògbó B ɖò fìfómɛ',
	'zbug_boucle' => 'Fífómɛ bìbɛmɛ',
	'zbug_boucle_recursive_undef' => 'Afɔ Fífómɛ bìbɛmɛ nɔ wà hwɛhwɛ yè mà sɔ ɖáyì é', # MODIF
	'zbug_champ_hors_boucle' => 'Tɛnmɛ  @champ@ é ɖò vò nú  Fífómɛ bìbɛmɛ',
	'zbug_champ_hors_motif' => 'Tɛnmɛ @champ@ é ɖò vò nú  Fífómɛ bìbɛmɛ @motif@', # MODIF
	'zbug_code' => 'Awòkɛn',
	'zbug_critere_inconnu' => 'Sɛnxwì yè mà tùn@critere@', # MODIF
	'zbug_distant_interdit' => 'Yè gbɛ ê má ɖò nù ɖé mɛ a', # MODIF
	'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
	'zbug_erreur_boucle_double' => 'tòbòtòbò@id@:tímɛ àzɔn wè', # MODIF
	'zbug_erreur_boucle_fermant' => 'tòbòtòbò@:cávì é nú ɔ ɖè á', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'tòbòtòbò ɔ sɔ gbè á', # MODIF
	'zbug_erreur_execution_page' => 'Afɔkílɛn ɖò àzɔ wìwàmɛ', # MODIF
	'zbug_erreur_filtre' => 'klɛn àfɔ ', # MODIF
	'zbug_erreur_meme_parent' => '{Nû_ɖòkpó ɔ} Fífómɛ bìbɛmɛ kɛɖɛ wɛ yè nɔ bló ná(Kplékplé lɛ) kabi (Akpáxwé lɛ)', # MODIF
	'zbug_erreur_squelette' => 'Afɔkílɛn (lɛ) ɖò tìtòmɛ ò mɛ ',
	'zbug_info_erreur_squelette' => 'àfɔkiklɛn ɖò gblogblojí',
	'zbug_inversion_ordre_inexistant' => 'Adà lílɛ nú wàlɔ é kó tíìn é', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION sans critère {pagination} ou employé dans une boucle recursive', # MODIF
	'zbug_parametres_inclus_incorrects' => ' wàlɔ yíyìɖémɛ  ɔ tɔn lɛ jlɔ à ', # MODIF
	'zbug_resultat' => 'Gbètà',
	'zbug_serveur_indefini' => 'Mɔxwìtíxwìtítàtɔ SQL tɔn ê mà tɛɖɛ é jì a ', # MODIF
	'zbug_table_inconnue' => 'Tìtòmɛ  SQL « @table@ »yè mà tùn',
];
